from Screens.Screen import Screen
from Components.ActionMap import ActionMap
from Components.Sources.List import List
from Components.Sources.StaticText import StaticText
from Components.Label import Label
from Tools.ISO639 import LanguageCodes
from Tools.Directories import resolveFilename, SCOPE_CURRENT_SKIN
from Tools.LoadPixmap import LoadPixmap
from enigma import eTimer
from emerlinremux import eMerlinRemux
# for localized messages
from . import _

class MerlinRemuxAudioSelectionList(List):

	def __init__(self, service, seek_pts, end_pts, audio):
		self.selectionpng = LoadPixmap(cached=True, path=resolveFilename(SCOPE_CURRENT_SKIN, "skin_default/icons/selectioncross.png"))
		self.audio_not = {}
		self.audio = audio
		self.service = service
		self.seek_pts = seek_pts
		self.end_pts = end_pts
		List.__init__(self, list = [], enableWrapAround=True, item_height=28, buildfunc=self.buildListEntry)
		
		
	def setAudioList(self):
		self.audio_not = {}
		audio_all = eMerlinRemux.getInstance().getAudioList(self.service.getPath(), self.seek_pts, self.end_pts);
		if self.audio:
			for a in audio_all:
				pid = a[0]
				found = False
				for aa in self.audio:
					if aa[0] == pid:
						found = True
						break
				if not found:
					self.audio_not[str(pid)] = pid
		self.setList(audio_all)	

	def buildListEntry(self, pid, lang, codec, description):
		language = self.getLanguageCode(lang)
		if self.audio_not.has_key(str(pid)):
			selected_png = None
		else:
			selected_png = self.selectionpng
		return (language, codec.upper(), description, selected_png)

	def ok_pressed(self):
		cur = self.current
		if cur:
			pid = cur[0]
			if self.audio_not.has_key(str(pid)):
				del self.audio_not[str(pid)]
			else:
				self.audio_not[str(pid)] = pid
			if self.master is not None and self.master.content is not None:
				self.master.content.invalidate()

	def getLanguageCode(self, lang):
		if LanguageCodes.has_key(lang):
			language = _(LanguageCodes[lang][0])
		elif lang == "und":
			language = _("<unknown>")
		else:
			language = lang
		return language

class MerlinRemuxAudioSelection(Screen):

	def __init__(self, session, service, seek_pts, end_pts, audio):
		Screen.__init__(self, session)
		self.session = session
		self.title = _("Merlin Remux Audio selection")
		self["actions"] = ActionMap(["WizardActions", "ColorActions"],
		{
			"back": self.cancel_pressed,
			"red": self.cancel_pressed,
			"green": self.green_pressed,
			"ok": self.ok_pressed,
		}, -1)
		self["list"] = MerlinRemuxAudioSelectionList(service, seek_pts, end_pts, audio)
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("Save"))
		self["key_yellow"] = StaticText("")
		self["key_blue"] = StaticText("")
		self["status"] = Label(_("Getting audio data..."))
		self.onShown.append(self.layoutFinished)
		self.startTimer = eTimer()
		self.startTimer_conn = self.startTimer.timeout.connect(self.startTimerCallback)
		
	def startTimerCallback(self):
		self["list"].setAudioList()
		self["status"].setText("")
		self["status"].hide()
	
	def layoutFinished(self):
		self.startTimer.start(0,1)

	def cancel_pressed(self):
		self.close(False,[], "")

	def ok_pressed(self):
		self["list"].ok_pressed()

	def green_pressed(self):
		audio = []
		audio_text = ""
		if self["list"].audio_not:
			for a in self["list"].list:
				if not self["list"].audio_not.has_key(str(a[0])):
					audio.append((a[0],a[1]))
					if audio_text != "":
						audio_text = audio_text + ", "
					audio_text = audio_text + "%s (%s)" % (self["list"].getLanguageCode(a[1]),a[2].upper())
		else:
			audio_text = _("All")
		self.close(True, audio, audio_text)

