from Screens.ChoiceBox import ChoiceBox
from enigma import eTimer, eActionMap

class MerlinRemuxChoiceBox(ChoiceBox):
	ALLOW_SUSPEND = True
	IS_DIALOG = True
	
	def __init__(self, session, title = "", list = [], keys = None, selection = 0, skin_name = [], windowTitle = None, allow_cancel = True, titlebartext = _("Input"), timeout = -1, text = ""):
		ChoiceBox.__init__(self, session, title, list, keys, selection, skin_name, windowTitle, allow_cancel, titlebartext)
		self.onClose.append(self.__onClose)
		self.autoActivationKeyPressedActionSlot = eActionMap.getInstance().bindAction('', -0x7FFFFFFF, self.autoActivationKeyPressed)
		self.timerRunning = False
		self.initTimeout(timeout)
		
	def initTimeout(self, timeout):
		self.timeout = timeout
		if timeout > 0:
			self.timer = eTimer()
			self.timer_conn = self.timer.timeout.connect(self.timerTick)
			self.onExecBegin.append(self.startTimer)
			self.origTitle = None
			if self.execing:
				self.timerTick()
			else:
				self.onShown.append(self.__onShown)
			self.timerRunning = True
		else:
			self.timerRunning = False
			
	def __onClose(self):
		self.autoActivationKeyPressedActionSlot = None
		
	def autoActivationKeyPressed(self, key = None, flag = None):
		self.stopTimer()
		return 0
	
	def __onShown(self):
		self.onShown.remove(self.__onShown)
		self.timerTick()

	def startTimer(self):
		self.timer.start(1000)

	def stopTimer(self):
		if self.timerRunning:
			del self.timer
			self.onExecBegin.remove(self.startTimer)
			self.setTitle(self.origTitle)
			self.timerRunning = False

	def timerTick(self):
		if self.execing:
			self.timeout -= 1
			if self.origTitle is None:
				self.origTitle = self.instance.getTitle()
			self.setTitle(self.origTitle + " (" + str(self.timeout) + ")")
			if self.timeout == 0:
				self.timer.stop()
				self.timerRunning = False
				self.timeoutCallback()
				
	def timeoutCallback(self):
		self.close(None)
