from Screens.MessageBox import MessageBox
from Tools.BoundFunction import boundFunction
from Tools import Notifications
from enigma import eServiceReference, eServiceCenter
from emerlinremux import eMerlinRemux, eMerlinRemuxState
from MerlinRemuxPlayerCutEditor import MerlinRemuxPlayer
from MerlinRemuxChoiceBox import MerlinRemuxChoiceBox
from os import path as os_path
# for localized messages
from . import _

Notifications.notificationQueue.registerDomain("MerlinRemux", _("Merlin Remux"), Notifications.ICON_DEFAULT)

class MerlinRemuxMessage(object):
	instance = None
	def __init__(self, session):
		self.session = session
		assert not MerlinRemuxMessage.instance, "only one MerlinRemuxMessage instance is allowed!"
		MerlinRemuxMessage.instance = self
		self.remuxDone_conn = eMerlinRemux.getInstance().remuxDone.connect(self.gotRemuxDone)

	def gotRemuxDone(self, in_filename, out_filename, message, state, show):
		if show or state == eMerlinRemuxState.error:
			if state == eMerlinRemuxState.cancelled:
				Notifications.AddNotification(MessageBox, _("%s\nremux progress was cancelled!") % (out_filename), type=MessageBox.TYPE_INFO, timeout=30, domain="MerlinRemux")
			elif state == eMerlinRemuxState.error:
				Notifications.AddNotification(MessageBox, _("%s\nremux progress finished with an error:\n%s") % (out_filename, message), type=MessageBox.TYPE_INFO, timeout=30, domain="MerlinRemux")
			else:
				self.showChoiceBox(in_filename, out_filename)
				
	def showChoiceBox(self, in_filename, out_filename):
		text = _("%s\nremux progress finished successfully!\n") % (out_filename)
		choicelist = []
		choicelist.append((_("Do nothing"), None))
		choicelist.append((_("Delete source file"), "CALLFUNC", boundFunction(self.delete, in_filename)))
		choicelist.append((_("Play file"), "CALLFUNC", boundFunction(self.playFile, out_filename)))
		try:
			from updateVideoDB import updateVideoDB
			choicelist.append((_("Replace source with remuxed file in VideoDB"), "CALLFUNC", boundFunction(updateVideoDB, self.session, in_filename, out_filename)))
		except: pass
		Notifications.AddNotification(MerlinRemuxChoiceBox, list = choicelist, selection=0, title=text, titlebartext=_("Merlin Remux"), timeout=30, text=text, is_dialog = False, domain = "MerlinRemux")

	def playFile(self, out_filename, *args):
		self.session.open(MerlinRemuxPlayer, eServiceReference(eServiceReference.idGST, 0, out_filename))

	def delete(self, in_filename, *args):
		if os_path.exists(in_filename): 
			service = eServiceReference(eServiceReference.idDVB, 0, in_filename)
			serviceHandler = eServiceCenter.getInstance()
			info = serviceHandler.info(service)
			name = info and info.getName(service) or _("this recording")
			# simulate first
			if not eMerlinRemux.getInstance().deleteFromDisk(1,service):
				self.session.openWithCallback(boundFunction(self.deleteConfirmed, service), MessageBox, _("Do you really want to delete %s?") % (name))
			else:
				self.session.open(MessageBox, _("You cannot delete this!"), MessageBox.TYPE_ERROR)
		else:
			self.session.open(MessageBox, _("%s does not exist!") % in_filename, MessageBox.TYPE_WARNING)

	def deleteConfirmed(self, service, confirmed):
		if confirmed:
			eMerlinRemux.getInstance().deleteFromDisk(0,service)

