from Screens.Screen import Screen
from Screens.InfoBarGenerics import InfoBarShowHide, InfoBarSeek, InfoBarAudioSelection, InfoBarAdditionalInfo, InfoBarServiceNotifications, InfoBarPVRState, InfoBarMoviePlayerSummarySupport, InfoBarSimpleEventView, InfoBarCueSheetSupport
from Components.ActionMap import HelpableActionMap
from Components.ServiceEventTracker import ServiceEventTracker, InfoBarBase
from Components.Sources.StaticText import StaticText
from Components.Label import Label
from enigma import iPlayableService
# for localized messages
from . import _

def getTimeString(t, value):
	if value == 0:
		if t:
			return _("from beginning")
		else:
			return _("to end")
	else:
		return "%02d:%02d:%02d" % (value / 3600, (value / 60) - ((value / 3600) * 60), value % 60)

class MerlinRemuxPlayer(InfoBarBase, InfoBarShowHide, InfoBarSeek, InfoBarAudioSelection, InfoBarAdditionalInfo, InfoBarServiceNotifications, InfoBarPVRState, InfoBarSimpleEventView, InfoBarMoviePlayerSummarySupport, Screen):

	ENABLE_RESUME_SUPPORT = False
	ALLOW_SUSPEND = True

	def __init__(self, session, ref):
		Screen.__init__(self, session)
		self.session = session
		self["actions"] = HelpableActionMap(self, "MoviePlayerActions",
			{
				"leavePlayer": (self.leavePlayer, _("leave movie player..."))
			})

		self["closeactions"] = HelpableActionMap(self, "WizardActions",
			{
				"back": (self.close, _("leave movie player..."))
			})

		self.allowPiP = False
		for x in InfoBarShowHide, InfoBarBase, InfoBarSeek, \
				InfoBarAudioSelection, InfoBarAdditionalInfo,  \
				InfoBarServiceNotifications, InfoBarPVRState,  InfoBarSimpleEventView, \
				InfoBarMoviePlayerSummarySupport:
			x.__init__(self)

		self.returning = False
		self.skinName = "MoviePlayer"
		self.lastservice = session.nav.getCurrentlyPlayingServiceReference()
		self.session.nav.playService(ref)
		self.onClose.append(self.__onClose)

	def leavePlayer(self):
		self.close()

	def doEofInternal(self, playing):
		self.close()

	def __onClose(self):
		self.session.nav.playService(self.lastservice)	

class MerlinRemuxCutEditorInOut(Screen):

	def __init__(self, session):
		Screen.__init__(self, session)

		self["key_red"] = StaticText(_("Delete start-time"))
		self["key_green"] = StaticText(_("Set start-time"))
		self["key_yellow"] = StaticText(_("Set end-time"))
		self["key_blue"] = StaticText(_("Delete end-time"))
		self["key_save"] = StaticText(_("OK -> save"))
		self["key_exit"] = StaticText(_("Exit -> cancel"))
		self["start"] = Label()
		self["stop"] = Label()

	def setStartStopText(self, t, value):
		timestr = getTimeString(t, value/90000)
		if t:
			self["start"].setText("%s %s" %(_("Start:"),timestr))
		else:
			self["stop"].setText("%s %s" %(_("Stop:"),timestr))

class MerlinRemuxCutEditor(InfoBarBase, InfoBarSeek, InfoBarAdditionalInfo, InfoBarServiceNotifications, InfoBarPVRState, InfoBarMoviePlayerSummarySupport, InfoBarCueSheetSupport, Screen):

	ENABLE_RESUME_SUPPORT = False
	ALLOW_SUSPEND = True

	def __init__(self, session, ref, seek_pts, end_pts):
		Screen.__init__(self, session)
		self.session = session
		self.seek_pts = seek_pts
		self.end_pts = end_pts
		self["actions"] = HelpableActionMap(self, "MoviePlayerActions",
			{
				"leavePlayer": (self.leavePlayer, _("leave movie player editor..."))
			})

		self["closeations"] = HelpableActionMap(self, "WizardActions", 
			{
				"back": (self.leavePlayerWithoutSaveing, _("leave movie player editor without saving...")),
				"ok": (self.leavePlayer, _("leave movie player editor..."))
			})

		self["cutactions"] = HelpableActionMap(self, "ColorActions", 
			{
				"red": (self.red_pressed, _("Delete start-time...")),
				"green": (self.green_pressed, _("Set start-time...")),
				"yellow": (self.yellow_pressed, _("Set end-time...")),
				"blue": (self.blue_pressed, _("Delete end-time..."))
			})

		if self.seek_pts != 0:
			self.__event_tracker = ServiceEventTracker(screen=self, eventmap=
				{
					iPlayableService.evStart: self.__serviceStarted,
				})

		self.allowPiP = False

		InfoBarBase.__init__(self)
		InfoBarSeek.__init__(self, actionmap = 'MerlinRemuxCutEditorSeekActions')
		for x in InfoBarAdditionalInfo, \
				InfoBarServiceNotifications, InfoBarPVRState, \
				InfoBarMoviePlayerSummarySupport, InfoBarCueSheetSupport:
			x.__init__(self)

		self.returning = False
		self.skinName = "MoviePlayer"
		self.lastservice = session.nav.getCurrentlyPlayingServiceReference()
		self.session.nav.playService(ref)
		self.onClose.append(self.__onClose)
		self.screenMerlinRemuxCutEditorInOut = self.session.instantiateDialog(MerlinRemuxCutEditorInOut)
		self.screenMerlinRemuxCutEditorInOut.show()
		self.onLayoutFinish.append(self.layoutFinished)

	def __serviceStarted(self):
		self.doSeek(self.seek_pts)

	def layoutFinished(self):
		self.screenMerlinRemuxCutEditorInOut.setStartStopText(True, self.seek_pts)
		self.screenMerlinRemuxCutEditorInOut.setStartStopText(False, self.end_pts)

	def leavePlayer(self):
		self.close((True, self.seek_pts, self.end_pts))

	def leavePlayerWithoutSaveing(self):
		self.close((False, self.seek_pts, self.end_pts))

	def doEofInternal(self, playing):
		if self.seekstate != self.SEEK_STATE_PAUSE:
			self.pauseService()

	def __onClose(self):
		self.session.deleteDialog(self.screenMerlinRemuxCutEditorInOut)
		self.session.nav.playService(self.lastservice)

	def checkSkipShowHideLock(self):
		pass

	def playpauseService(self):
		if self.seekstate != self.SEEK_STATE_PLAY and not self.isStateSlowMotion(self.seekstate):
			self.unPauseService()
		else:
			self.pauseService()

	def red_pressed(self):
		self.seek_pts = 0
		self.screenMerlinRemuxCutEditorInOut.setStartStopText(True, self.seek_pts)

	def green_pressed(self):
		service = self.session.nav.getCurrentService()
		seek = service.seek()
		seek_pts = seek.getPlayPosition()[1]
		if self.end_pts == 0 or (self.end_pts != 0 and seek_pts < self.end_pts):
			self.seek_pts = seek_pts
			self.screenMerlinRemuxCutEditorInOut.setStartStopText(True, self.seek_pts)

	def blue_pressed(self):
		self.end_pts = 0
		self.screenMerlinRemuxCutEditorInOut.setStartStopText(False, self.end_pts)

	def yellow_pressed(self):
		service = self.session.nav.getCurrentService()
		seek = service.seek()
		end_pts = seek.getPlayPosition()[1]
		if self.seek_pts == 0 or (self.seek_pts != 0 and self.seek_pts < end_pts):
			self.end_pts = end_pts
			self.screenMerlinRemuxCutEditorInOut.setStartStopText(False, self.end_pts)

