from Screens.Screen import Screen
from Screens.LocationBox import LocationBox
from Screens.FixedMenu import FixedMenu
from Screens.MessageBox import MessageBox
from Components.ConfigList import ConfigListScreen
from Components.config import config, ConfigText, ConfigYesNo, ConfigSelection, getConfigListEntry
from Components.ActionMap import ActionMap
from Components.Sources.List import List
from Components.Sources.StaticText import StaticText
from enigma import eServiceCenter
from os import path as os_path
from MerlinRemuxPlayerCutEditor import MerlinRemuxCutEditor, getTimeString
from MerlinRemuxAudioSelection import MerlinRemuxAudioSelection
from emerlinremux import eMerlinRemux
# for localized messages
from . import _


class MerlinRemuxScreenContextMenu(FixedMenu):
	
	RET_FILENAME_FROM_METADATA = 0
	RET_FILENAME_AS_SOURCE = 1

	def __init__(self, session):
		menu = [(_("back"), self.close)]
		menu.append((_("Create filename from meta-data"), self.filename_from_metadata))
		menu.append((_("Same filename as source"), self.filename_as_source))
		FixedMenu.__init__(self, session, _("Merlin Remux"), menu)

	def filename_from_metadata(self):
		self.close(self.RET_FILENAME_FROM_METADATA)

	def filename_as_source(self):
		self.close(self.RET_FILENAME_AS_SOURCE)

class MerlinRemuxLocationBox(LocationBox):
	
	IS_DIALOG = True

	def __init__(self, session, text, dir, minFree = None):
		inhibitDirs = ["/bin", "/boot", "/dev", "/etc", "/lib", "/proc", "/sbin", "/sys", "/usr", "/var"]
		LocationBox.__init__(self, session, text = text, currDir = dir, bookmarks = config.plugins.merlinremux.locations, autoAdd = True, editDir = True, inhibitDirs = inhibitDirs, minFree = minFree)
		

class MerlinRemuxScreen(ConfigListScreen, Screen):
	
	def __init__(self, session, service):
		Screen.__init__(self, session)
		self.session = session
		self.title = _("Merlin Remux")
	
		self.service = service
		
		self["actions"] = ActionMap(["WizardActions", "ColorActions", "MovieSelectionActions"],
		{
			"back": self.close,
			"ok": self.ok_pressed,
			"green": self.green_pressed,
			"blue": self.blue_pressed,
			"yellow" :self.yellow_pressed,
			"contextMenu": self.contextMenu_pressed,

		}, -1)
		
		self.seek_pts = 0
		self.end_pts = 0
		self.audio = []

		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("Start Remux"))
		self["key_yellow"] = StaticText(_("Audio"))
		self["key_blue"] = StaticText(_("Cut"))
		
		self.in_filename = ConfigText(default = self.service.getPath())
		self.in_filename.enabled = False
		
		self.out_filename = ConfigText(default = "", fixed_size = False)
		if config.plugins.merlinremux.usemetaasfilename.value:
			self.switchFilename(MerlinRemuxScreenContextMenu.RET_FILENAME_FROM_METADATA)
		else:
			self.switchFilename(MerlinRemuxScreenContextMenu.RET_FILENAME_AS_SOURCE)
		
		tmp = config.plugins.merlinremux.locations.value
		last_locations = config.plugins.merlinremux.last_locations.value
		path = os_path.dirname(self.service.getPath()) + "/"
		if path not in tmp:
			tmp.append(path)

		if last_locations != "":
			if last_locations not in tmp:
				tmp.append(last_locations)
			default = last_locations
		else:
			default = path
		

		self.target_dir = ConfigSelection(default=default, choices = tmp)
		self.target_dir_config = getConfigListEntry(_("Target dir:"), self.target_dir)
		self.seek_pts_text = ConfigText(default = getTimeString(True, self.seek_pts))
		self.seek_pts_text.enabled = False
		self.end_pts_text = ConfigText(default = getTimeString(False, self.end_pts))
		self.end_pts_text.enabled = False
		self.audio_text = ConfigText(default = _("All"))
		self.audio_text.enabled = False

		cfglist = [ ]
		cfglist.append(getConfigListEntry(_("Source:"), self.in_filename))
		cfglist.append(getConfigListEntry(_("Target:"), self.out_filename))
		cfglist.append(self.target_dir_config)
		self.seek_pts_text_config = getConfigListEntry(_("Start:"), self.seek_pts_text)
		cfglist.append(self.seek_pts_text_config)
		self.end_pts_text_config = getConfigListEntry(_("Stop:"), self.end_pts_text)
		cfglist.append(self.end_pts_text_config)
		self.audio_text_config = getConfigListEntry(_("Audio:"), self.audio_text)
		cfglist.append(self.audio_text_config)
		cfglist.append(getConfigListEntry(_("Create meta file:"), config.plugins.merlinremux.create_meta))
		cfglist.append(getConfigListEntry(_("Create eit file:"), config.plugins.merlinremux.create_eit))
		cfglist.append(getConfigListEntry(_("Show messagebox after remuxing:"), config.plugins.merlinremux.showmsgdone))
		ConfigListScreen.__init__(self, cfglist, session)

	def contextMenu_pressed(self):
		self.session.openWithCallback(self.menuCallback, MerlinRemuxScreenContextMenu)
		
	def switchFilename(self, type):
		if type == MerlinRemuxScreenContextMenu.RET_FILENAME_AS_SOURCE:
			name = os_path.splitext(os_path.basename(self.service.getPath()))[0]
		else:
			serviceHandler = eServiceCenter.getInstance()
			info = serviceHandler.info(self.service)
			name = info and info.getName(self.service) or ''
			if name.endswith(".ts"):
				name = name.split(".")[0].strip()
		if len(name) != 0:
			self.out_filename.value = self.checkFilename(name)
		config.plugins.merlinremux.usemetaasfilename.value = type == MerlinRemuxScreenContextMenu.RET_FILENAME_FROM_METADATA
		
	def menuCallback(self, *result):
		if not len(result):
			return
		result = result[0]
		if result == MerlinRemuxScreenContextMenu.RET_FILENAME_FROM_METADATA or result == MerlinRemuxScreenContextMenu.RET_FILENAME_AS_SOURCE:
			self.switchFilename(result)
			self["config"].invalidate(self.out_filename)

	def ok_pressed(self):
		cur = self["config"].getCurrent()
		if cur == self.target_dir_config:
			self.chooseDestination()
		elif cur == self.audio_text_config:
			self.yellow_pressed()
		elif cur == self.seek_pts_text_config or cur == self.end_pts_text_config:
			self.blue_pressed()

	def pathSelected(self, res):
		if res is not None:
			if config.plugins.merlinremux.locations.value != self.target_dir.choices:
				self.target_dir.setChoices(config.plugins.merlinremux.locations.value, default=res)
			self.target_dir.value = res
			self["config"].invalidateCurrent()

	def chooseDestination(self):
		self.session.openWithCallback(self.pathSelected, MerlinRemuxLocationBox, _("Choose target folder"), self.target_dir.value, minFree = 100)
		
	def playerEditorCallback(self, data):
		if data and data[0]:
			self.seek_pts = data[1]
			self.end_pts = data[2]
			self.seek_pts_text.value = getTimeString(True, self.seek_pts/90000)
			self.end_pts_text.value = getTimeString(False, self.end_pts/90000)

	def blue_pressed(self):
		self.session.openWithCallback(self.playerEditorCallback, MerlinRemuxCutEditor, self.service, self.seek_pts, self.end_pts)

	def green_pressed(self):
		filename = os_path.join(self.target_dir.value,"%s.mkv" % self.out_filename.value)
		if not os_path.exists(filename):
			self.do_remux(True)	
		else:
			self.session.openWithCallback(self.do_remux, MessageBox, _("Filename\n%s\nalready exists.\nOverwrite?")%filename)

	def do_remux(self, result):
		if not result:
			return
		self.out_filename.value = self.checkFilename(self.out_filename.value)
		self["config"].invalidate(self.out_filename)
		result = eMerlinRemux.getInstance().remux(self.service.getPath(), os_path.join(self.target_dir.value,"%s.mkv" % self.out_filename.value), self.seek_pts, self.end_pts, self.audio, config.plugins.merlinremux.create_meta.value, config.plugins.merlinremux.create_eit.value, config.plugins.merlinremux.showmsgdone.value)
		if result == 0:
			config.plugins.merlinremux.usemetaasfilename.save()
			config.plugins.merlinremux.last_locations.value = self.target_dir.value
			config.plugins.merlinremux.last_locations.save()
			config.plugins.merlinremux.showmsgdone.save()
			self.close()
		elif result == 1:
			self.session.open(MessageBox, _("Only ts to mkv is allowed!"), type = MessageBox.TYPE_WARNING)
		elif result == 2:
			self.session.open(MessageBox, _("End-Time must be greater than start-time!"), type = MessageBox.TYPE_WARNING)

	def yellow_pressed(self):
		self.session.openWithCallback(self.audioSelectionCallback, MerlinRemuxAudioSelection, self.service, self.seek_pts, self.end_pts, self.audio)

	def audioSelectionCallback(self, result, audio, audio_text):
		if result:
			self.audio = audio
			self.audio_text.value = audio_text
			self["config"].invalidate(self.audio_text)

	def checkFilename(self, filename):
		for invalid in '*<>\+:=/";[]|': #'?*<>.,\+:=/";[]|'
			if invalid == ':':
				filename = filename.replace(invalid,'-')
			else:
				filename = filename.replace(invalid,'_')
		return filename
