from Plugins.Plugin import PluginDescriptor
from Components.config import config, ConfigSubsection, ConfigLocations, ConfigYesNo, ConfigText
from Screens.MessageBox import MessageBox
from Tools.BoundFunction import boundFunction
from enigma import eEnv, eServiceReference
from MerlinRemuxListScreen import MerlinRemuxListScreen
from MerlinRemuxScreen import MerlinRemuxScreen
from MerlinRemuxMessage import MerlinRemuxMessage
from emerlinremux import eMerlinRemux
from Screens.Standby import TryQuitMainloop, inTryQuitMainloop
# for localized messages
from . import _

config.plugins.merlinremux = ConfigSubsection()
config.plugins.merlinremux.locations = ConfigLocations(default=["/hdd/movie/"])
config.plugins.merlinremux.showmsgdone = ConfigYesNo(default=False)
config.plugins.merlinremux.usemetaasfilename = ConfigYesNo(default=False)
config.plugins.merlinremux.last_locations = ConfigText(default="")
config.plugins.merlinremux.create_meta = ConfigYesNo(default=True)
config.plugins.merlinremux.create_eit = ConfigYesNo(default=True)

baseTryQuitMainloop__init__ = None

def MerlinRemuxTryQuitMainloop__init__(self, session, retvalue=1, timeout=-1, default_yes = True):
	if eMerlinRemux.getInstance().isRunning():
		self.retval=retvalue
		reason = _("There is a remux progress running in background!\n")
		if retvalue == 16:
			reason += _("Really reboot into Recovery Mode?\n")
		if retvalue == 1:
			MessageBox.__init__(self, session, reason+_("Really shutdown now?"), type = MessageBox.TYPE_YESNO, timeout = timeout, default = default_yes)
		elif retvalue == 2:
			MessageBox.__init__(self, session, reason+_("Really reboot now?"), type = MessageBox.TYPE_YESNO, timeout = timeout, default = default_yes)
		elif retvalue == 4:
			pass
		elif retvalue == 16:
			MessageBox.__init__(self, session, reason+_("You won't be able to leave Recovery Mode without physical access to the device!"), type = MessageBox.TYPE_YESNO, timeout = timeout, default = default_yes)
		else:
			MessageBox.__init__(self, session, reason+_("Really restart now?"), type = MessageBox.TYPE_YESNO, timeout = timeout, default = default_yes)
		self.skinName = "MessageBox"
		session.nav.record_event.append(self.getRecordEvent)
		self.connected = True
		self.onShow.append(boundFunction(onShow_, self))
		self.onHide.append(boundFunction(onHide_, self))
	else:
		baseTryQuitMainloop__init__(self, session, retvalue, timeout, default_yes)

def onShow_(self):
	global inTryQuitMainloop
	inTryQuitMainloop = True

def onHide_(self):
	global inTryQuitMainloop
	inTryQuitMainloop = False


			

def instanceclass(session, **kwargs):
	MerlinRemuxMessage(session)


def merlinremuxlistscreen(session,**kwargs):
	session.open(MerlinRemuxListScreen)

def movielist(session, service, **kwargs):
	if not (service.flags & eServiceReference.mustDescent):
		if service.getPath().endswith('.ts'):
			session.open(MerlinRemuxScreen, service)
			
def mainloop(reason, **kwargs):
	if reason == 0:
		global baseTryQuitMainloop__init__
		baseTryQuitMainloop__init__ = TryQuitMainloop.__init__
		TryQuitMainloop.__init__ = MerlinRemuxTryQuitMainloop__init__

def Plugins(**kwargs):
	list = [PluginDescriptor(name=_("Remux List"), description=_("remux ts files to mkv"), where = PluginDescriptor.WHERE_EVENTINFO, fnc=merlinremuxlistscreen)]
	list.append(PluginDescriptor(where = PluginDescriptor.WHERE_SESSIONSTART, fnc = skin_loader))
	list.append(PluginDescriptor(name=_("Remux to mkv"), description=_("Remux to mkv"), where = PluginDescriptor.WHERE_MOVIELIST, fnc = movielist))
	list.append(PluginDescriptor(where = PluginDescriptor.WHERE_SESSIONSTART, fnc = mainloop))
	list.append(PluginDescriptor(where = PluginDescriptor.WHERE_SESSIONSTART, fnc = instanceclass))
	return list

def skin_loader(reason, **kwargs):
	if reason == 0:
		from skin import loadSkin, loadSingleSkinData, dom_skins
		from enigma import getDesktop
		from Tools.Directories import resolveFilename, SCOPE_CURRENT_PLUGIN
		skindir =  eEnv.resolve("${libdir}/enigma2/python/Plugins/Extensions/MerlinRemuxer/skins/")
		desktopSize = getDesktop(0).size().height()
		skinFile = resolveFilename(SCOPE_CURRENT_PLUGIN, skindir + "skin_%d.xml" % desktopSize)
		loadSkin(skinFile, "")
		path, dom_skin = dom_skins[-1:][0]
		loadSingleSkinData(getDesktop(0), dom_skin, path)

