from Screens.MessageBox import MessageBox
from os import path as os_path, stat as os_stat
from stat import ST_SIZE as stat_ST_SIZE
from datetime import datetime	
from Plugins.Extensions.VideoDB.DatabaseConnection import OpenDatabaseForWriting, ClientID
from Plugins.Extensions.VideoDB.DatabaseFunctions import getMountPoint, getPathID, MetaData
# for localized messages
from . import _

def updateVideoDB(session, in_filename, out_filename, *args):
	from_path, from_filename = os_path.split(in_filename)
	to_path, to_filename = os_path.split(out_filename)		
	connection, error = OpenDatabaseForWriting()
	if connection is not None:
		connection.text_factory = str
		cursor = connection.cursor()
		realpath = os_path.realpath(from_path)
		ismounted, mountpoint = getMountPoint(realpath)
		relativePath = os_path.relpath(realpath, mountpoint)
		if relativePath == ".": # mountpoint == relativePath
			relativePath = ""
		to_realpath = os_path.realpath(to_path)
		to_ismounted, to_mountpoint = getMountPoint(to_realpath)
		to_relativePath = os_path.relpath(to_realpath, to_mountpoint)
		if to_relativePath == ".": # mountpoint == relativePath
			to_relativePath = ""
		client_id = ClientID.instance.getClientID()
		cursor.execute('SELECT movie_id FROM Movies INNER JOIN Paths ON movies.path_id = paths.path_id INNER JOIN mountpoints on Paths.link_id = Mountpoints.link_id WHERE filename = ? and paths.path = ? and mountpoints.mountpoint = ? and mountpoints.client_id = ?;', (from_filename, relativePath, mountpoint, client_id))
		row = cursor.fetchone()
		if row is not None:
			movieID = row[0]
			serviceID = 0x1001
			modified = datetime.utcnow()
			filesize = 0
			if os_path.exists(os_path.join(to_realpath,to_filename)): 
				fileInfo = os_stat(os_path.join(to_realpath,to_filename))
				filesize = fileInfo[stat_ST_SIZE]
			metaData = MetaData(serviceID, to_realpath, to_filename)
			pathID = getPathID(cursor, to_path)
			cursor.execute('UPDATE Movies SET duration = %d, filesize = %d, modified = "%s", recording = 0, ac3=%d, dts=%d, fivepointone =%d, stereo=%d, codec="%s", container="%s", res_width=%d, res_height=%d, framerate=%f, widescreen=%d, hd=%d, video_codec_text="%s", serviceid = 4097, path_id = %d, filename = "%s" WHERE movie_id = %d;' % (metaData.movieLength, filesize, modified, metaData.ac3, metaData.dts, metaData.FivePointOne, metaData.stereo, metaData.codec, metaData.container, metaData.res_width, metaData.res_height, metaData.framerate, metaData.widescreen, metaData.hd, metaData.video_codec_text, pathID, to_filename, movieID))
			# 8. Audio 
			if metaData.audio_infos is not None:
				cursor.execute('DELETE FROM Audio where movie_id = %d;' % (movieID))
				for audio in metaData.audio_infos:
					cursor.execute('INSERT INTO Audio (movie_id, codec, language, description,codec_id, channels, bitrate, audio_text) VALUES(%d, "%s","%s","%s",%d,%d, %d, "%s");' % (movieID, audio[0], audio[1], audio[2], audio[3], audio[4], audio[5], audio[6]))
			connection.commit()
			session.open(MessageBox, _("VideoDB: database updated with remuxed file!"), MessageBox.TYPE_INFO)
		else:
			session.open(MessageBox, _("VideoDB: can not find source video in database!"), MessageBox.TYPE_WARNING)
		cursor.close() 
		connection.close()
	else:
		session.open(MessageBox, _("VideoDB: Database Error!"), MessageBox.TYPE_ERROR)		

